--- old/usr/src/cmd/zonecfg/zonecfg.c	Mon Jul  7 08:39:36 2014
+++ new/usr/src/cmd/zonecfg/zonecfg.c	Mon Jul  7 08:39:36 2014
@@ -22,6 +22,7 @@
 /*
  * Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.
  * Copyright 2014 Nexenta Systems, Inc.  All rights reserved.
+ * Copyright 2014 Gary Mills
  */
 
 /*
@@ -931,16 +932,19 @@
 		space = strchr(pager, ' ');
 		if (space)
 			*space = '\0';
-		if (stat(pager, &statbuf) == 0) {
+		if (*pager == '/' && stat(pager, &statbuf) != 0) {
+			zerr(gettext("PAGER %s does not exist (%s)."),
+			    pager, strerror(errno));
+		} else {
 			if (space)
 				*space = ' ';
-			if ((newfp = popen(pager, "w")) != NULL) {
+			if ((newfp = popen(pager, "w")) == NULL) {
+				zerr(gettext("PAGER %s open failed (%s)."),
+				    pager, strerror(errno));
+			} else {
 				need_to_close = B_TRUE;
 				fp = newfp;
 			}
-		} else {
-			zerr(gettext("PAGER %s does not exist (%s)."),
-			    pager, strerror(errno));
 		}
 	}
 
@@ -1273,8 +1277,17 @@
 		(void) fprintf(fp, "\t%s\t\t%s, %s\n", rt_to_str(RT_ADMIN),
 		    pt_to_str(PT_USER), pt_to_str(PT_AUTHS));
 	}
-	if (need_to_close)
-		(void) pclose(fp);
+	if (need_to_close) {
+		int status;
+
+		status = pclose(fp);
+		if (status == -1)
+			zerr(gettext("PAGER %s close failed (%s)."),
+			    pager, strerror(errno));
+		else if (WIFEXITED(status) && WEXITSTATUS(status) != 0)
+			zerr(gettext("PAGER %s exit code: %d."),
+			    pager, WEXITSTATUS(status));
+	}
 }
 
 static void
@@ -5362,16 +5375,19 @@
 		space = strchr(pager, ' ');
 		if (space)
 			*space = '\0';
-		if (stat(pager, &statbuf) == 0) {
+		if (*pager == '/' && stat(pager, &statbuf) != 0) {
+			zerr(gettext("PAGER %s does not exist (%s)."),
+			    pager, strerror(errno));
+		} else {
 			if (space)
 				*space = ' ';
-			if ((fp = popen(pager, "w")) != NULL)
-				need_to_close = B_TRUE;
-			else
+			if ((fp = popen(pager, "w")) == NULL) {
 				fp = stdout;
-		} else {
-			zerr(gettext("PAGER %s does not exist (%s)."),
-			    pager, strerror(errno));
+				zerr(gettext("PAGER %s open failed (%s)."),
+				    pager, strerror(errno));
+			} else {
+				need_to_close = B_TRUE;
+			}
 		}
 
 		setbuf(fp, NULL);
@@ -5561,8 +5577,17 @@
 	}
 
 cleanup:
-	if (need_to_close)
-		(void) pclose(fp);
+	if (need_to_close) {
+		int status;
+
+		status = pclose(fp);
+		if (status == -1)
+			zerr(gettext("PAGER %s close failed (%s)."),
+			    pager, strerror(errno));
+		else if (WIFEXITED(status) && WEXITSTATUS(status) != 0)
+			zerr(gettext("PAGER %s exit code: %d."),
+			    pager, WEXITSTATUS(status));
+	}
 }
 
 /*
--- old/usr/src/lib/libzonecfg/common/libzonecfg.c	Mon Jul  7 08:39:36 2014
+++ new/usr/src/lib/libzonecfg/common/libzonecfg.c	Mon Jul  7 08:39:36 2014
@@ -20,6 +20,7 @@
  */
 
 /*
+ * Copyright 2014 Gary Mills
  * Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.
  */
 
@@ -1767,7 +1768,7 @@
 		return (B_FALSE);
 	prop_result = xmlStrcmp(gotten_prop, (const xmlChar *) user_prop);
 	xmlFree(gotten_prop);
-	return ((prop_result == 0));
+	return ((prop_result == 0));	/* empty strings will match */
 }
 
 static int
@@ -2255,7 +2256,7 @@
 		phys_match = match_prop(cur, DTD_ATTR_PHYSICAL,
 		    tabptr->zone_nwif_physical);
 
-		if ((addr_match || allowed_addr_match) && phys_match) {
+		if (addr_match && allowed_addr_match && phys_match) {
 			xmlUnlinkNode(cur);
 			xmlFreeNode(cur);
 			return (Z_OK);
